pub struct SetConfigResult {
pub result: SetConfigResultCode,
pub owner: Owner,
pub current: Modulation,
}Expand description
Payload of OK in response to SET_CONFIG (PROTOCOL.md 6.3).
current_modulation and current_params always reflect what is
actually programmed into the radio at the moment the response was
constructed, regardless of whether this call caused the change.
Fields
result: SetConfigResultCodeowner: Ownercurrent: ModulationImplementations